//
//  RSColoredBox.m
//  FlexTime
//
//  Created by Daniel Jalkut on 10/25/06.
//  Copyright 2006 Red Sweater Software. All rights reserved.
//

#import "RSColoredBox.h"


@implementation RSColoredBox

- (id)initWithFrame:(NSRect)frameRect
{
	if (self = [super initWithFrame:frameRect])
	{
		mBoxBorderColor = [[NSColor whiteColor] retain];
	}
	
	return self;
}

- (void) dealloc
{
	[mBoxBorderColor release];
	[super dealloc];
}

- (void) drawRect:(NSRect)rect
{
	if ([self boxType] != NSBoxSeparator)
	{
		[super drawRect:rect];
	}
	else
	{
		// Draw a 1-pixel line right through the middle of our bounds, whatever they may be.
		// This makes it work correctly with InterfaceBuilder "separator" items, which claim
		// to have a 1 pixel girth but actually have a 5 pixel girth!
		NSRect myBounds = [self bounds];
		if (myBounds.size.height > myBounds.size.width)
		{
			// Vertical line - normalize width to 1 pixel and center it in the rect
			myBounds = NSMakeRect(floor(NSMidX(myBounds)), ceil(NSMinY(myBounds)), 1, NSHeight(myBounds));					
		}
		else
		{
			// Horizontal line - normalize width to 1 pixel and center it in the rect
			myBounds = NSMakeRect(ceil(NSMinX(myBounds)), floor(NSMidY(myBounds)), NSWidth(myBounds), 1);			
		}
		[mBoxBorderColor set];
		NSRectFillUsingOperation(myBounds, NSCompositeSourceOver);
	}
}

//  boxBorderColor 
- (NSColor *) boxBorderColor
{
    return mBoxBorderColor; 
}

- (void) setBoxBorderColor: (NSColor *) theBoxBorderColor
{
    if (mBoxBorderColor != theBoxBorderColor)
    {
        [mBoxBorderColor release];
        mBoxBorderColor = [theBoxBorderColor retain];
    }
}

@end
